"""
    Sysruntime API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.sysruntime_hw_connection_spec import SysruntimeHWConnectionSpec
from pensando_dss.psm.model.sysruntime_hw_connection_stats import SysruntimeHWConnectionStats
from pensando_dss.psm.model.sysruntime_hw_connection_status import SysruntimeHWConnectionStatus
globals()['SysruntimeHWConnectionSpec'] = SysruntimeHWConnectionSpec
globals()['SysruntimeHWConnectionStats'] = SysruntimeHWConnectionStats
globals()['SysruntimeHWConnectionStatus'] = SysruntimeHWConnectionStatus
from pensando_dss.psm.psm.model.sysruntime_hw_connection_get_response import SysruntimeHWConnectionGetResponse


class TestSysruntimeHWConnectionGetResponse(unittest.TestCase):
    """SysruntimeHWConnectionGetResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSysruntimeHWConnectionGetResponse(self):
        """Test SysruntimeHWConnectionGetResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = SysruntimeHWConnectionGetResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Auth API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.api_object_meta import ApiObjectMeta
from pensando_dss.psm.model.auth_authentication_policy_spec import AuthAuthenticationPolicySpec
from pensando_dss.psm.model.auth_authentication_policy_status import AuthAuthenticationPolicyStatus
globals()['ApiObjectMeta'] = ApiObjectMeta
globals()['AuthAuthenticationPolicySpec'] = AuthAuthenticationPolicySpec
globals()['AuthAuthenticationPolicyStatus'] = AuthAuthenticationPolicyStatus
from pensando_dss.psm.psm.model.auth_authentication_policy import AuthAuthenticationPolicy


class TestAuthAuthenticationPolicy(unittest.TestCase):
    """AuthAuthenticationPolicy unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testAuthAuthenticationPolicy(self):
        """Test AuthAuthenticationPolicy"""
        # FIXME: construct object with mandatory attributes with example values
        # model = AuthAuthenticationPolicy()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Search API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from pensando_dss.psm.api_client import ApiClient, Endpoint as _Endpoint
from pensando_dss.psm.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
import pensando_dss.psm as psm
from pensando_dss.psm.model.search_policy_search_request import SearchPolicySearchRequest
from pensando_dss.psm.model.search_policy_search_response import SearchPolicySearchResponse
from pensando_dss.psm.model.search_search_request import SearchSearchRequest
from pensando_dss.psm.model.search_search_response import SearchSearchResponse


class SearchV1Api(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        def __get_policy_query1(
            self,
            **kwargs
        ):
            """Security Policy Query  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_policy_query1(async_req=True)
            >>> result = thread.get()


            Keyword Args:
                tenant (str): Tenant Name, to perform query within a Tenant's scope. The default tenant is \"default\". In the backend this field gets auto-filled & validated by apigw-hook based on user login context.. [optional]
                kinds ([str]): Kind of the policy that this request should act on. It should be either NetworkSecurityPolicy or IPSecPolicy.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                SearchPolicySearchResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            return self.call_with_http_info(**kwargs)

        self.get_policy_query1 = _Endpoint(
            settings={
                'response_type': (SearchPolicySearchResponse,),
                'auth': [],
                'endpoint_path': '/search/v1/policy-query',
                'operation_id': 'get_policy_query1',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'tenant',
                    'kinds',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'tenant':
                        (str,),
                    'kinds':
                        ([str],),
                },
                'attribute_map': {
                    'tenant': 'tenant',
                    'kinds': 'kinds',
                },
                'location_map': {
                    'tenant': 'query',
                    'kinds': 'query',
                },
                'collection_format_map': {
                    'kinds': 'csv',
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_policy_query1
        )

        def __get_query1(
            self,
            **kwargs
        ):
            """Structured or free-form search  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_query1(async_req=True)
            >>> result = thread.get()


            Keyword Args:
                query_string (str): Simple query string This can be specified as URI parameter. For advanced query cases, Users should use specify SearchQuery and pass the SearchRequest in a GET/POST Body The max query-string length is 256 bytes. Length of string should be between 0 and 256.. [optional]
                _from (int): From represents the start offset (zero based), used in paginated search requests The results returned would be in the range [From ... From+MaxResults-1] This can be specified as URI parameter. Default value is 0 and valid range is 0..8192. Value should be between 0 and 8192.. [optional]
                query_categories ([str]): OR of Categories to be matched, AND and Exclude are not supported for this type The max category string length is 64 bytes. Length of string should be between 0 and 64.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                SearchSearchResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            return self.call_with_http_info(**kwargs)

        self.get_query1 = _Endpoint(
            settings={
                'response_type': (SearchSearchResponse,),
                'auth': [],
                'endpoint_path': '/search/v1/query',
                'operation_id': 'get_query1',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'query_string',
                    '_from',
                    'query_categories',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'query_string':
                        (str,),
                    '_from':
                        (int,),
                    'query_categories':
                        ([str],),
                },
                'attribute_map': {
                    'query_string': 'query-string',
                    '_from': 'from',
                    'query_categories': 'query.categories',
                },
                'location_map': {
                    'query_string': 'query',
                    '_from': 'query',
                    'query_categories': 'query',
                },
                'collection_format_map': {
                    'query_categories': 'csv',
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_query1
        )

        def __post_policy_query(
            self,
            body,
            **kwargs
        ):
            """Security Policy Query  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.post_policy_query(body, async_req=True)
            >>> result = thread.get()

            Args:
                body (SearchPolicySearchRequest):

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                SearchPolicySearchResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['body'] = \
                body
            return self.call_with_http_info(**kwargs)

        self.post_policy_query = _Endpoint(
            settings={
                'response_type': (SearchPolicySearchResponse,),
                'auth': [],
                'endpoint_path': '/search/v1/policy-query',
                'operation_id': 'post_policy_query',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'body',
                ],
                'required': [
                    'body',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'body':
                        (SearchPolicySearchRequest,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__post_policy_query
        )

        def __post_query(
            self,
            body,
            **kwargs
        ):
            """Structured or free-form search  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.post_query(body, async_req=True)
            >>> result = thread.get()

            Args:
                body (SearchSearchRequest):

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                SearchSearchResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['body'] = \
                body
            return self.call_with_http_info(**kwargs)

        self.post_query = _Endpoint(
            settings={
                'response_type': (SearchSearchResponse,),
                'auth': [],
                'endpoint_path': '/search/v1/query',
                'operation_id': 'post_query',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'body',
                ],
                'required': [
                    'body',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'body':
                        (SearchSearchRequest,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__post_query
        )



"""
    Cluster API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.cluster_auto_msg_credentials_watch_helper_watch_event import ClusterAutoMsgCredentialsWatchHelperWatchEvent
globals()['ClusterAutoMsgCredentialsWatchHelperWatchEvent'] = ClusterAutoMsgCredentialsWatchHelperWatchEvent
from pensando_dss.psm.psm.model.cluster_auto_msg_credentials_watch_helper import ClusterAutoMsgCredentialsWatchHelper


class TestClusterAutoMsgCredentialsWatchHelper(unittest.TestCase):
    """ClusterAutoMsgCredentialsWatchHelper unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testClusterAutoMsgCredentialsWatchHelper(self):
        """Test ClusterAutoMsgCredentialsWatchHelper"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ClusterAutoMsgCredentialsWatchHelper()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
